/* Copyright (C) 2008 P.L. Lucas
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, 
 * Boston, MA 02111-1307, USA. 
 */



#include <gtk/gtk.h>
#include <glade/glade.h>
#include <vte/vte.h>
#include <vte/reaper.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "postscript_options.h"
#include "plot2d_options_xml.h"

static GladeXML *xml;
static GtkWidget *vte;
static gchar *datafile_name=NULL;



/*************************************************************************************************/
void on_select_file_button_clicked(GtkWidget *widget, gpointer user_data) {
	GtkWidget *entry=glade_xml_get_widget(xml,"function_entry");
	datafile_name=select_file("Select data file",datafile_name);
	if( datafile_name!= NULL )
		gtk_entry_set_text(GTK_ENTRY(entry), datafile_name);
}

/*************************************************************************************************/
void on_add_button_clicked(GtkWidget *widget, gpointer user_data) {
	char comando[5000];
	GtkWidget *aux;
    	comando[0]='\0';
    	aux=glade_xml_get_widget(xml,"auto_scale_checkbutton");
    	if(!gtk_toggle_button_get_active ((GtkToggleButton *)aux)){
    		aux=glade_xml_get_widget(xml,"x_min_entry");
		strcat(comando,"[");
		strcat(comando, gtk_editable_get_chars
				(GTK_EDITABLE(aux),0,-1));
		strcat(comando,":");
		aux=glade_xml_get_widget(xml,"x_max_entry");
		strcat(comando, gtk_editable_get_chars
				(GTK_EDITABLE(aux),0,-1));
		strcat(comando,"]");
		aux=glade_xml_get_widget(xml,"y_min_entry");
		strcat(comando,"[");
		strcat(comando, gtk_editable_get_chars
				(GTK_EDITABLE(aux),0,-1));
		strcat(comando,":");
		aux=glade_xml_get_widget(xml,"y_max_entry");
		strcat(comando, gtk_editable_get_chars
				(GTK_EDITABLE(aux),0,-1));
		strcat(comando,"]");
	}
	aux=glade_xml_get_widget(xml,"datafile_checkbutton");
    	if(!gtk_toggle_button_get_active ((GtkToggleButton *)aux)){
    		aux=glade_xml_get_widget(xml,"function_entry");
		strcat(comando," ");
		strcat(comando, gtk_editable_get_chars
				(GTK_EDITABLE(aux),0,-1));
	} else {
		strcat(comando," \"");
		strcat(comando,datafile_name);
		strcat(comando,"\" using ");
		aux=glade_xml_get_widget(xml,"using_entry");
		strcat(comando," ");
		strcat(comando, gtk_editable_get_chars
				(GTK_EDITABLE(aux),0,-1));
	}
	aux=glade_xml_get_widget(xml,"no_title_checkbutton");
    	if(!gtk_toggle_button_get_active ((GtkToggleButton *)aux)){
    		aux=glade_xml_get_widget(xml,"title_entry");
		strcat(comando," title \"");
		strcat(comando, gtk_editable_get_chars
				(GTK_EDITABLE(aux),0,-1));
		strcat(comando,"\"");
	}
	strcat(comando," with ");
    	aux=glade_xml_get_widget(xml,"combo-entry1");
    	strcat(comando, gtk_editable_get_chars
			(GTK_EDITABLE(aux),0,-1));
	vte_terminal_feed_child(VTE_TERMINAL(vte), comando, strlen(comando));
}


/*************************************************************************************************/
void destroy_window(GtkWidget *widget, gpointer user_data) {
	gtk_widget_destroy(GTK_WIDGET(user_data));
	g_object_unref(xml);
}

/*************************************************************************************************/
void create_plot_options(GtkWidget *vte_widget){
	GError *error;
	GtkWidget *window, *cancel;
	gint result;
	vte=vte_widget;
	/* load the interface */
    	/*xml = glade_xml_new(GLADE_PLOT_OPTIONS, NULL, NULL);*/
    	xml = glade_xml_new_from_buffer( plot2d_options_xml, strlen(plot2d_options_xml), NULL, NULL );
   	 if(xml==NULL) {
   	 	printf("Error: plot2d_options.glade not found.\n\n");
 	   	exit(0);
 	   }
 	   /* connect the signals in the interface */
 	glade_xml_signal_autoconnect(xml);
    	window=glade_xml_get_widget(xml,"plot2d_options_window");
    	g_signal_connect (GTK_OBJECT (window),
                     "delete-event",
                     G_CALLBACK (destroy_window),
                     (gpointer) window);
        cancel=glade_xml_get_widget(xml,"cancel_button");
        g_signal_connect (GTK_OBJECT (cancel),
                     "clicked",
                     G_CALLBACK (destroy_window),
                     (gpointer) window);
}


/*************************************************************************************************/
gchar *select_file(gchar *window_name, gchar *filename){
	GtkWidget *file_selection=gtk_file_selection_new(window_name);
	gint result;
	static gchar *file_name=NULL;
	if( filename!= NULL ) gtk_file_selection_set_filename ( (GtkFileSelection *)file_selection, filename);
	else if( file_name!= NULL ) gtk_file_selection_set_filename ( (GtkFileSelection *)file_selection, file_name);
	gtk_widget_hide(GTK_FILE_SELECTION(file_selection)->ok_button);
	gtk_widget_hide(GTK_FILE_SELECTION(file_selection)->cancel_button);
	gtk_dialog_add_buttons((GtkDialog *)file_selection,
                                             	  GTK_STOCK_OK,
                                                  GTK_RESPONSE_OK,
                                                  GTK_STOCK_CANCEL,
                                                  GTK_RESPONSE_REJECT,
                                                  NULL);
	result=gtk_dialog_run(GTK_DIALOG(file_selection));
	if( result == GTK_RESPONSE_OK ) {
		const gchar *selected_filename= gtk_file_selection_get_filename (GTK_FILE_SELECTION (file_selection));
		if( file_name!= NULL ) free(file_name);
		file_name=(char *)malloc(sizeof(gchar)*(strlen(selected_filename)+1));
		sprintf(file_name,"%s",selected_filename);
		gtk_widget_destroy(file_selection);
		return file_name;
	}
	gtk_widget_destroy(file_selection);
	return NULL;
}



